from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 4 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def factory(self):
		"""factory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_factory'):
			from .Factory import FactoryCls
			self._factory = FactoryCls(self._core, self._cmd_group)
		return self._factory

	@property
	def update(self):
		"""update commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_update'):
			from .Update import UpdateCls
			self._update = UpdateCls(self._core, self._cmd_group)
		return self._update

	def export(self) -> None:
		"""SCPI: CALibration:DATA:EXPort \n
		Snippet: driver.calibration.data.export() \n
		No command help available \n
		"""
		self._core.io.write(f'CALibration:DATA:EXPort')

	def export_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CALibration:DATA:EXPort \n
		Snippet: driver.calibration.data.export_with_opc() \n
		No command help available \n
		Same as export, but waits for the operation to complete before continuing further. Use the RsAreg.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALibration:DATA:EXPort', opc_timeout_ms)

	def clone(self) -> 'DataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BaseCls:
	"""Base commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("base", core, parent)

	def get_attenuation(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:BASE:ATTenuation \n
		Snippet: value: int = driver.source.areGenerator.radar.base.get_attenuation() \n
		Defines the attenuation affecting all radar objects. Together with the individual attenuation for a single radar object,
		it forms the total attenuation for the specific object. \n
			:return: areg_base_att: integer Range: -50 to 150, Unit: dB
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:BASE:ATTenuation?')
		return Conversions.str_to_int(response)

	def set_attenuation(self, areg_base_att: int) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:BASE:ATTenuation \n
		Snippet: driver.source.areGenerator.radar.base.set_attenuation(areg_base_att = 1) \n
		Defines the attenuation affecting all radar objects. Together with the individual attenuation for a single radar object,
		it forms the total attenuation for the specific object. \n
			:param areg_base_att: integer Range: -50 to 150, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(areg_base_att)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:RADar:BASE:ATTenuation {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImageCls:
	"""Image commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("image", core, parent)

	# noinspection PyTypeChecker
	def get_format_py(self) -> enums.HardCopyImageFormat:
		"""SCPI: HCOPy:IMAGe:FORMat \n
		Snippet: value: enums.HardCopyImageFormat = driver.hardCopy.image.get_format_py() \n
		Selects the graphic format for the hard copy. You can use both commands alternatively. \n
			:return: format_py: No help available
		"""
		response = self._core.io.query_str('HCOPy:IMAGe:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.HardCopyImageFormat)

	def set_format_py(self, format_py: enums.HardCopyImageFormat) -> None:
		"""SCPI: HCOPy:IMAGe:FORMat \n
		Snippet: driver.hardCopy.image.set_format_py(format_py = enums.HardCopyImageFormat.BMP) \n
		Selects the graphic format for the hard copy. You can use both commands alternatively. \n
			:param format_py: BMP| JPG| XPM| PNG
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.HardCopyImageFormat)
		self._core.io.write(f'HCOPy:IMAGe:FORMat {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DialogCls:
	"""Dialog commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dialog", core, parent)

	def close(self, dialog_id: str) -> None:
		"""SCPI: DISPlay:DIALog:CLOSe \n
		Snippet: driver.display.dialog.close(dialog_id = 'abc') \n
		Closes the specified dialog. \n
			:param dialog_id: string To find out the dialog identifier, use the query method RsAreg.Display.Dialog.id. The DialogName part of the query result is sufficient.
		"""
		param = Conversions.value_to_quoted_str(dialog_id)
		self._core.io.write(f'DISPlay:DIALog:CLOSe {param}')

	def close_all(self) -> None:
		"""SCPI: DISPlay:DIALog:CLOSe:ALL \n
		Snippet: driver.display.dialog.close_all() \n
		Closes all open dialogs. \n
		"""
		self._core.io.write(f'DISPlay:DIALog:CLOSe:ALL')

	def close_all_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: DISPlay:DIALog:CLOSe:ALL \n
		Snippet: driver.display.dialog.close_all_with_opc() \n
		Closes all open dialogs. \n
		Same as close_all, but waits for the operation to complete before continuing further. Use the RsAreg.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DISPlay:DIALog:CLOSe:ALL', opc_timeout_ms)

	def get_id(self) -> str:
		"""SCPI: DISPlay:DIALog:ID \n
		Snippet: value: str = driver.display.dialog.get_id() \n
		Returns the dialog identifiers of the open dialogs in a string separated by blanks. \n
			:return: dialog_id_list: DialogID#1 DialogID#2 ... DialogID#n Dialog identifiers are string without blanks. Blanks are represented as $$. Dialog identifiers DialogID are composed of two main parts: DialogName[OptionalParts] DialogName Meaningful information, mandatory input parameter for the commands: method RsAreg.Display.Dialog.open method RsAreg.Display.Dialog.close Optional parts String of $X values, where X is a character, interpreted as follows: $qDialogQualifier: optional dialog qualifier, usually the letter A or B, as displayed in the dialog title. $iInstances: comma-separated list of instance indexes, given in the order h,c,s,d,g,u,0. Default is zero; the terminating ',0' can be omitted. $tTabIds: comma-separated indexes or tab names; required, if a dialog is composed of several tabs. $xLeft$yTop$hLeft$wTop: position and size; superfluous information.
		"""
		response = self._core.io.query_str('DISPlay:DIALog:ID?')
		return trim_str_response(response)

	def open(self, dialog_id: str) -> None:
		"""SCPI: DISPlay:DIALog:OPEN \n
		Snippet: driver.display.dialog.open(dialog_id = 'abc') \n
		Opens the specified dialog. \n
			:param dialog_id: string To find out the dialog identifier, use the query method RsAreg.Display.Dialog.id. The DialogName part of the query result is mandatory.
		"""
		param = Conversions.value_to_quoted_str(dialog_id)
		self._core.io.write(f'DISPlay:DIALog:OPEN {param}')



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PageCls:
	"""Page commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("page", core, parent)

	def set(self) -> None:
		"""SCPI: DIAGnostic<HW>:DEBug:PAGE \n
		Snippet: driver.diagnostic.debug.page.set() \n
		No command help available \n
		"""
		self._core.io.write(f'DIAGnostic<HwInstance>:DEBug:PAGE')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: DIAGnostic<HW>:DEBug:PAGE \n
		Snippet: driver.diagnostic.debug.page.set_with_opc() \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsAreg.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DIAGnostic<HwInstance>:DEBug:PAGE', opc_timeout_ms)

	def get_catalog(self) -> List[str]:
		"""SCPI: DIAGnostic<HW>:DEBug:PAGE:CATalog \n
		Snippet: value: List[str] = driver.diagnostic.debug.page.get_catalog() \n
		No command help available \n
			:return: diag_debug_page_id_cat: No help available
		"""
		response = self._core.io.query_str('DIAGnostic<HwInstance>:DEBug:PAGE:CATalog?')
		return Conversions.str_to_str_list(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	# noinspection PyTypeChecker
	def get_recall(self) -> enums.InclExcl:
		"""SCPI: [SOURce<HW>]:POWer:[LEVel]:[IMMediate]:RCL \n
		Snippet: value: enums.InclExcl = driver.source.power.level.immediate.get_recall() \n
		No command help available \n
			:return: rcl: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:LEVel:IMMediate:RCL?')
		return Conversions.str_to_scalar_enum(response, enums.InclExcl)

	def set_recall(self, rcl: enums.InclExcl) -> None:
		"""SCPI: [SOURce<HW>]:POWer:[LEVel]:[IMMediate]:RCL \n
		Snippet: driver.source.power.level.immediate.set_recall(rcl = enums.InclExcl.EXCLude) \n
		No command help available \n
			:param rcl: No help available
		"""
		param = Conversions.enum_scalar_to_str(rcl, enums.InclExcl)
		self._core.io.write(f'SOURce<HwInstance>:POWer:LEVel:IMMediate:RCL {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MtimeCls:
	"""Mtime commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mtime", core, parent)

	def set(self, mtime: float, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:FILTer:NSRatio:MTIMe \n
		Snippet: driver.sense.power.filterPy.nsRatio.mtime.set(mtime = 1.0, channel = repcap.Channel.Default) \n
		Sets an upper limit for the settling time of the auto-averaging filter in the NSRatio mode and thus limits the length of
		the filter. The filter type is set with command method RsAreg.Sense.Power.FilterPy.TypePy.set. \n
			:param mtime: float Range: 1 to 999.99
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
		"""
		param = Conversions.decimal_value_to_str(mtime)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:FILTer:NSRatio:MTIMe {param}')

	def get(self, channel=repcap.Channel.Default) -> float:
		"""SCPI: SENSe<CH>:[POWer]:FILTer:NSRatio:MTIMe \n
		Snippet: value: float = driver.sense.power.filterPy.nsRatio.mtime.get(channel = repcap.Channel.Default) \n
		Sets an upper limit for the settling time of the auto-averaging filter in the NSRatio mode and thus limits the length of
		the filter. The filter type is set with command method RsAreg.Sense.Power.FilterPy.TypePy.set. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
			:return: mtime: float Range: 1 to 999.99"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe{channel_cmd_val}:POWer:FILTer:NSRatio:MTIMe?')
		return Conversions.str_to_float(response)



"""RsAreg instrument driver
	:version: 4.80.71.19
	:copyright: 2023 by Rohde & Schwarz GMBH & Co. KG
	:license: MIT, see LICENSE for more details.
"""

__version__ = '4.80.71.19'

# Main class
from RsAreg.RsAreg import RsAreg

# Bin data format
from RsAreg.Internal.Conversions import BinIntFormat, BinFloatFormat

# Exceptions
from RsAreg.Internal.InstrumentErrors import RsInstrException, TimeoutException, StatusException, UnexpectedResponseException, ResourceError, DriverValueError

# Callback Event Argument prototypes
from RsAreg.Internal.IoTransferEventArgs import IoTransferEventArgs

# Logging Mode
from RsAreg.Internal.ScpiLogger import LoggingMode

# enums
from RsAreg import enums

# repcaps
from RsAreg import repcap



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	def get(self, board_id: List[str], channel=repcap.Channel.Default) -> List[str]:
		"""SCPI: DIAGnostic<HW>:EEPRom<CH>:BIDentifier:CATalog \n
		Snippet: value: List[str] = driver.diagnostic.eeprom.bidentifier.catalog.get(board_id = ['abc1', 'abc2', 'abc3'], channel = repcap.Channel.Default) \n
		No command help available \n
			:param board_id: No help available
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Eeprom')
			:return: board_id: No help available"""
		param = Conversions.list_to_csv_quoted_str(board_id)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'DIAGnostic<HwInstance>:EEPRom{channel_cmd_val}:BIDentifier:CATalog? {param}')
		return Conversions.str_to_str_list(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 47 total commands, 8 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	@property
	def areGenerator(self):
		"""areGenerator commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_areGenerator'):
			from .AreGenerator import AreGeneratorCls
			self._areGenerator = AreGeneratorCls(self._core, self._cmd_group)
		return self._areGenerator

	@property
	def bb(self):
		"""bb commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_bb'):
			from .Bb import BbCls
			self._bb = BbCls(self._core, self._cmd_group)
		return self._bb

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def inputPy(self):
		"""inputPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def modulation(self):
		"""modulation commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def path(self):
		"""path commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_path'):
			from .Path import PathCls
			self._path = PathCls(self._core, self._cmd_group)
		return self._path

	@property
	def power(self):
		"""power commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def roscillator(self):
		"""roscillator commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_roscillator'):
			from .Roscillator import RoscillatorCls
			self._roscillator = RoscillatorCls(self._core, self._cmd_group)
		return self._roscillator

	def preset(self) -> None:
		"""SCPI: SOURce<HW>:PRESet \n
		Snippet: driver.source.preset() \n
		Presets all parameters which are related to the selected signal path. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SOURce<HW>:PRESet \n
		Snippet: driver.source.preset_with_opc() \n
		Presets all parameters which are related to the selected signal path. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsAreg.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:PRESet', opc_timeout_ms)

	def clone(self) -> 'SourceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SourceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ObjectCls:
	"""Object commands group definition. 7 total commands, 5 Subgroups, 0 group commands
	Repeated Capability: ObjectIx, default value after init: ObjectIx.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("object", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_objectIx_get', 'repcap_objectIx_set', repcap.ObjectIx.Nr1)

	def repcap_objectIx_set(self, objectIx: repcap.ObjectIx) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to ObjectIx.Default
		Default value after init: ObjectIx.Nr1"""
		self._cmd_group.set_repcap_enum_value(objectIx)

	def repcap_objectIx_get(self) -> repcap.ObjectIx:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def attenuation(self):
		"""attenuation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_attenuation'):
			from .Attenuation import AttenuationCls
			self._attenuation = AttenuationCls(self._core, self._cmd_group)
		return self._attenuation

	@property
	def range(self):
		"""range commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_range'):
			from .Range import RangeCls
			self._range = RangeCls(self._core, self._cmd_group)
		return self._range

	@property
	def rcs(self):
		"""rcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rcs'):
			from .Rcs import RcsCls
			self._rcs = RcsCls(self._core, self._cmd_group)
		return self._rcs

	@property
	def subChannel(self):
		"""subChannel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_subChannel'):
			from .SubChannel import SubChannelCls
			self._subChannel = SubChannelCls(self._core, self._cmd_group)
		return self._subChannel

	def clone(self) -> 'ObjectCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ObjectCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DbypassCls:
	"""Dbypass commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dbypass", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:DBYPass:[STATe] \n
		Snippet: value: bool = driver.source.areGenerator.radar.dbypass.get_state() \n
		Enable to bypass the Doppler stage. For details, see 'Enable Doppler Bypass'. \n
			:return: areg_radar_dop_byp: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:DBYPass:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, areg_radar_dop_byp: bool) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:DBYPass:[STATe] \n
		Snippet: driver.source.areGenerator.radar.dbypass.set_state(areg_radar_dop_byp = False) \n
		Enable to bypass the Doppler stage. For details, see 'Enable Doppler Bypass'. \n
			:param areg_radar_dop_byp: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(areg_radar_dop_byp)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:RADar:DBYPass:STATe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.PowSensFiltType, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:FILTer:TYPE \n
		Snippet: driver.sense.power.filterPy.typePy.set(type_py = enums.PowSensFiltType.AUTO, channel = repcap.Channel.Default) \n
		Selects the filter mode. The filter length is the multiplier for the time window and thus directly affects the
		measurement time. \n
			:param type_py: AUTO| USER| NSRatio AUTO Automatically selects the filter length, depending on the measured value. The higher the power, the shorter the filter length, and vice versa. USER Allows you to set the filter length manually. As the filter-length takes effect as a multiplier of the measurement time, you can achieve constant measurement times. NSRatio Selects the filter length (averaging factor) according to the criterion that the intrinsic noise of the sensor (2 standard deviations) does not exceed the specified noise content. You can define the noise content with command method RsAreg.Sense.Power.FilterPy.NsRatio.set. Note: To avoid long settling times when the power is low, you can limit the averaging factor limited with the 'timeout' parameter (method RsAreg.Sense.Power.FilterPy.NsRatio.Mtime.set) .
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.PowSensFiltType)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:FILTer:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.PowSensFiltType:
		"""SCPI: SENSe<CH>:[POWer]:FILTer:TYPE \n
		Snippet: value: enums.PowSensFiltType = driver.sense.power.filterPy.typePy.get(channel = repcap.Channel.Default) \n
		Selects the filter mode. The filter length is the multiplier for the time window and thus directly affects the
		measurement time. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
			:return: type_py: AUTO| USER| NSRatio AUTO Automatically selects the filter length, depending on the measured value. The higher the power, the shorter the filter length, and vice versa. USER Allows you to set the filter length manually. As the filter-length takes effect as a multiplier of the measurement time, you can achieve constant measurement times. NSRatio Selects the filter length (averaging factor) according to the criterion that the intrinsic noise of the sensor (2 standard deviations) does not exceed the specified noise content. You can define the noise content with command method RsAreg.Sense.Power.FilterPy.NsRatio.set. Note: To avoid long settling times when the power is low, you can limit the averaging factor limited with the 'timeout' parameter (method RsAreg.Sense.Power.FilterPy.NsRatio.Mtime.set) ."""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe{channel_cmd_val}:POWer:FILTer:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.PowSensFiltType)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Types import DataType
from ...Internal.Utilities import trim_str_response
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BgInfoCls:
	"""BgInfo commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bgInfo", core, parent)

	def get(self, board: str = None) -> str:
		"""SCPI: DIAGnostic<HW>:BGINfo \n
		Snippet: value: str = driver.diagnostic.bgInfo.get(board = 'abc') \n
		Queries information on the modules available in the instrument, using the variant and revision state. \n
			:param board: string Module name, as queried with the command method RsAreg.Diagnostic.BgInfo.catalog. To retrieve a complete list of all modules, omit the parameter. The length of the list is variable and depends on the instrument equipment configuration.
			:return: bg_info: Module name Module stock number incl. variant Module revision Module serial number List of comma-separated entries, one entry per module. Each entry for one module consists of four parts that are separated by space characters."""
		param = ArgSingleList().compose_cmd_string(ArgSingle('board', board, DataType.String, None, is_optional=True))
		response = self._core.io.query_str(f'DIAGnostic<HwInstance>:BGINfo? {param}'.rstrip())
		return trim_str_response(response)

	def get_catalog(self) -> List[str]:
		"""SCPI: DIAGnostic<HW>:BGINfo:CATalog \n
		Snippet: value: List[str] = driver.diagnostic.bgInfo.get_catalog() \n
		Queries the names of the assemblies available in the instrument. \n
			:return: catalog: string List of all assemblies; the values are separated by commas The length of the list is variable and depends on the instrument equipment configuration.
		"""
		response = self._core.io.query_str('DIAGnostic<HwInstance>:BGINfo:CATalog?')
		return Conversions.str_to_str_list(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CustomizeCls:
	"""Customize commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("customize", core, parent)

	def set(self, board: str, index: int, sub_board: int, channel=repcap.Channel.Default) -> None:
		"""SCPI: DIAGnostic<HW>:EEPRom<CH>:CUSTomize \n
		Snippet: driver.diagnostic.eeprom.customize.set(board = 'abc', index = 1, sub_board = 1, channel = repcap.Channel.Default) \n
		No command help available \n
			:param board: No help available
			:param index: No help available
			:param sub_board: No help available
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Eeprom')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('board', board, DataType.String), ArgSingle('index', index, DataType.Integer), ArgSingle('sub_board', sub_board, DataType.Integer))
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'DIAGnostic<HwInstance>:EEPRom{channel_cmd_val}:CUSTomize {param}'.rstrip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EirpCls:
	"""Eirp commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("eirp", core, parent)

	# noinspection PyTypeChecker
	def get_sensor(self) -> enums.AregPowSens:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:EIRP:SENSor \n
		Snippet: value: enums.AregPowSens = driver.source.areGenerator.radar.eirp.get_sensor() \n
		Queries if and which sensor is used to measure the EIRP value. \n
			:return: areg_pow_sen_selec: SEN4| SEN3| SEN2| SEN1| UDEFined UDEFined No sensor is selected for EIRP measurement. However, there can be power sensors connected to one of the 'USB' connectors or the 'Sensor' connector of the R&S AREG100A. Sent the method RsAreg.Slist.listPy query to find out if and which power sensors are connected to the instrument. SEN4|SEN3|SEN2|SEN1 Indicates that a power sensor is connected to the frontend. The number SENx indicates the subsequent number in the sensor mapping list of the corresponding sensor. Observe the most left column in the 'NRP Sensor Mapping' dialog. See method RsAreg.Slist.Element.Mapping.set.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:EIRP:SENSor?')
		return Conversions.str_to_scalar_enum(response, enums.AregPowSens)

	def set_sensor(self, areg_pow_sen_selec: enums.AregPowSens) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:EIRP:SENSor \n
		Snippet: driver.source.areGenerator.radar.eirp.set_sensor(areg_pow_sen_selec = enums.AregPowSens.SEN1) \n
		Queries if and which sensor is used to measure the EIRP value. \n
			:param areg_pow_sen_selec: SEN4| SEN3| SEN2| SEN1| UDEFined UDEFined No sensor is selected for EIRP measurement. However, there can be power sensors connected to one of the 'USB' connectors or the 'Sensor' connector of the R&S AREG100A. Sent the method RsAreg.Slist.listPy query to find out if and which power sensors are connected to the instrument. SEN4|SEN3|SEN2|SEN1 Indicates that a power sensor is connected to the frontend. The number SENx indicates the subsequent number in the sensor mapping list of the corresponding sensor. Observe the most left column in the 'NRP Sensor Mapping' dialog. See method RsAreg.Slist.Element.Mapping.set.
		"""
		param = Conversions.enum_scalar_to_str(areg_pow_sen_selec, enums.AregPowSens)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:RADar:EIRP:SENSor {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:EIRP \n
		Snippet: value: float = driver.source.areGenerator.radar.eirp.get_value() \n
		Queries the measured EIRP value of the radar sensor. For details, see 'EIRP calculation'. \n
			:return: areg_radar_eirp: float Range: -150 to 150
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:EIRP?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPyCls:
	"""FilterPy commands group definition. 6 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("filterPy", core, parent)

	@property
	def length(self):
		"""length commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	@property
	def nsRatio(self):
		"""nsRatio commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsRatio'):
			from .NsRatio import NsRatioCls
			self._nsRatio = NsRatioCls(self._core, self._cmd_group)
		return self._nsRatio

	@property
	def sonce(self):
		"""sonce commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sonce'):
			from .Sonce import SonceCls
			self._sonce = SonceCls(self._core, self._cmd_group)
		return self._sonce

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def clone(self) -> 'FilterPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def set(self, areg_ob_dopp_freq: float, objectIx=repcap.ObjectIx.Default, subchannel=repcap.Subchannel.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJect<CH>:[SUBChannel<ST>]:DOPPler:FREQuency \n
		Snippet: driver.source.areGenerator.object.subChannel.doppler.frequency.set(areg_ob_dopp_freq = 1.0, objectIx = repcap.ObjectIx.Default, subchannel = repcap.Subchannel.Default) \n
		No command help available \n
			:param areg_ob_dopp_freq: No help available
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
		"""
		param = Conversions.decimal_value_to_str(areg_ob_dopp_freq)
		objectIx_cmd_val = self._cmd_group.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OBJect{objectIx_cmd_val}:SUBChannel{subchannel_cmd_val}:DOPPler:FREQuency {param}')

	def get(self, objectIx=repcap.ObjectIx.Default, subchannel=repcap.Subchannel.Default) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJect<CH>:[SUBChannel<ST>]:DOPPler:FREQuency \n
		Snippet: value: float = driver.source.areGenerator.object.subChannel.doppler.frequency.get(objectIx = repcap.ObjectIx.Default, subchannel = repcap.Subchannel.Default) \n
		No command help available \n
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:return: areg_ob_dopp_freq: No help available"""
		objectIx_cmd_val = self._cmd_group.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:OBJect{objectIx_cmd_val}:SUBChannel{subchannel_cmd_val}:DOPPler:FREQuency?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HardCopyCls:
	"""HardCopy commands group definition. 17 total commands, 4 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hardCopy", core, parent)

	@property
	def device(self):
		"""device commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_device'):
			from .Device import DeviceCls
			self._device = DeviceCls(self._core, self._cmd_group)
		return self._device

	@property
	def file(self):
		"""file commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def image(self):
		"""image commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_image'):
			from .Image import ImageCls
			self._image = ImageCls(self._core, self._cmd_group)
		return self._image

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import ExecuteCls
			self._execute = ExecuteCls(self._core, self._cmd_group)
		return self._execute

	def get_data(self) -> bytes:
		"""SCPI: HCOPy:DATA \n
		Snippet: value: bytes = driver.hardCopy.get_data() \n
		Transfers the hard copy data directly as a NByte stream to the remote client. \n
			:return: data: block data
		"""
		response = self._core.io.query_bin_block('HCOPy:DATA?')
		return response

	# noinspection PyTypeChecker
	def get_region(self) -> enums.HardCopyRegion:
		"""SCPI: HCOPy:REGion \n
		Snippet: value: enums.HardCopyRegion = driver.hardCopy.get_region() \n
		Selects the area to be copied. You can create a snapshot of the screen or an active dialog. \n
			:return: region: ALL| DIALog
		"""
		response = self._core.io.query_str('HCOPy:REGion?')
		return Conversions.str_to_scalar_enum(response, enums.HardCopyRegion)

	def set_region(self, region: enums.HardCopyRegion) -> None:
		"""SCPI: HCOPy:REGion \n
		Snippet: driver.hardCopy.set_region(region = enums.HardCopyRegion.ALL) \n
		Selects the area to be copied. You can create a snapshot of the screen or an active dialog. \n
			:param region: ALL| DIALog
		"""
		param = Conversions.enum_scalar_to_str(region, enums.HardCopyRegion)
		self._core.io.write(f'HCOPy:REGion {param}')

	def clone(self) -> 'HardCopyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HardCopyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RecordCls:
	"""Record commands group definition. 7 total commands, 2 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("record", core, parent)

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def wrap(self):
		"""wrap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_wrap'):
			from .Wrap import WrapCls
			self._wrap = WrapCls(self._core, self._cmd_group)
		return self._wrap

	def get(self, index: List[str]) -> List[str]:
		"""SCPI: SYSTem:PROFiling:RECord \n
		Snippet: value: List[str] = driver.system.profiling.record.get(index = ['abc1', 'abc2', 'abc3']) \n
		No command help available \n
			:param index: No help available
			:return: index: No help available"""
		param = Conversions.list_to_csv_quoted_str(index)
		response = self._core.io.query_str(f'SYSTem:PROFiling:RECord? {param}')
		return Conversions.str_to_str_list(response)

	def clear(self) -> None:
		"""SCPI: SYSTem:PROFiling:RECord:CLEar \n
		Snippet: driver.system.profiling.record.clear() \n
		No command help available \n
		"""
		self._core.io.write(f'SYSTem:PROFiling:RECord:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:PROFiling:RECord:CLEar \n
		Snippet: driver.system.profiling.record.clear_with_opc() \n
		No command help available \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsAreg.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:PROFiling:RECord:CLEar', opc_timeout_ms)

	def get_ignore(self) -> float:
		"""SCPI: SYSTem:PROFiling:RECord:IGNore \n
		Snippet: value: float = driver.system.profiling.record.get_ignore() \n
		No command help available \n
			:return: count: No help available
		"""
		response = self._core.io.query_str('SYSTem:PROFiling:RECord:IGNore?')
		return Conversions.str_to_float(response)

	def set_ignore(self, count: float) -> None:
		"""SCPI: SYSTem:PROFiling:RECord:IGNore \n
		Snippet: driver.system.profiling.record.set_ignore(count = 1.0) \n
		No command help available \n
			:param count: No help available
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'SYSTem:PROFiling:RECord:IGNore {param}')

	def save(self, filename: str) -> None:
		"""SCPI: SYSTem:PROFiling:RECord:SAVE \n
		Snippet: driver.system.profiling.record.save(filename = 'abc') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SYSTem:PROFiling:RECord:SAVE {param}')

	def clone(self) -> 'RecordCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RecordCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UnitsCls:
	"""Units commands group definition. 6 total commands, 0 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("units", core, parent)

	# noinspection PyTypeChecker
	def get_angle(self) -> enums.UnitAngleAreg:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:ANGLe \n
		Snippet: value: enums.UnitAngleAreg = driver.source.areGenerator.units.get_angle() \n
		No command help available \n
			:return: areg_unit_agle: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:UNITs:ANGLe?')
		return Conversions.str_to_scalar_enum(response, enums.UnitAngleAreg)

	def set_angle(self, areg_unit_agle: enums.UnitAngleAreg) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:ANGLe \n
		Snippet: driver.source.areGenerator.units.set_angle(areg_unit_agle = enums.UnitAngleAreg.DEGree) \n
		No command help available \n
			:param areg_unit_agle: No help available
		"""
		param = Conversions.enum_scalar_to_str(areg_unit_agle, enums.UnitAngleAreg)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:UNITs:ANGLe {param}')

	# noinspection PyTypeChecker
	def get_doppler(self) -> enums.AregDopplerUnit:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:DOPPler \n
		Snippet: value: enums.AregDopplerUnit = driver.source.areGenerator.units.get_doppler() \n
		Defines if the radial velocity is defined as Doppler speed or frequency. \n
			:return: areg_obj_dopp_unit: SPEed| FREQuency
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:UNITs:DOPPler?')
		return Conversions.str_to_scalar_enum(response, enums.AregDopplerUnit)

	def set_doppler(self, areg_obj_dopp_unit: enums.AregDopplerUnit) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:DOPPler \n
		Snippet: driver.source.areGenerator.units.set_doppler(areg_obj_dopp_unit = enums.AregDopplerUnit.FREQuency) \n
		Defines if the radial velocity is defined as Doppler speed or frequency. \n
			:param areg_obj_dopp_unit: SPEed| FREQuency
		"""
		param = Conversions.enum_scalar_to_str(areg_obj_dopp_unit, enums.AregDopplerUnit)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:UNITs:DOPPler {param}')

	# noinspection PyTypeChecker
	def get_range(self) -> enums.UnitLengthAreg:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:RANGe \n
		Snippet: value: enums.UnitLengthAreg = driver.source.areGenerator.units.get_range() \n
		Defines the range unit. \n
			:return: areg_unit_range: M| CM| FT M Meter CM Centimeter FT Feet
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:UNITs:RANGe?')
		return Conversions.str_to_scalar_enum(response, enums.UnitLengthAreg)

	def set_range(self, areg_unit_range: enums.UnitLengthAreg) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:RANGe \n
		Snippet: driver.source.areGenerator.units.set_range(areg_unit_range = enums.UnitLengthAreg.CM) \n
		Defines the range unit. \n
			:param areg_unit_range: M| CM| FT M Meter CM Centimeter FT Feet
		"""
		param = Conversions.enum_scalar_to_str(areg_unit_range, enums.UnitLengthAreg)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:UNITs:RANGe {param}')

	# noinspection PyTypeChecker
	def get_rcs(self) -> enums.UnitRcsAreg:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:RCS \n
		Snippet: value: enums.UnitRcsAreg = driver.source.areGenerator.units.get_rcs() \n
		Defines the unit of the radar cross section. \n
			:return: areg_unit_rcs: DBSM| SM DBSM dB relative to one square meter. SM m2 (square meters) .
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:UNITs:RCS?')
		return Conversions.str_to_scalar_enum(response, enums.UnitRcsAreg)

	def set_rcs(self, areg_unit_rcs: enums.UnitRcsAreg) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:RCS \n
		Snippet: driver.source.areGenerator.units.set_rcs(areg_unit_rcs = enums.UnitRcsAreg.DBSM) \n
		Defines the unit of the radar cross section. \n
			:param areg_unit_rcs: DBSM| SM DBSM dB relative to one square meter. SM m2 (square meters) .
		"""
		param = Conversions.enum_scalar_to_str(areg_unit_rcs, enums.UnitRcsAreg)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:UNITs:RCS {param}')

	# noinspection PyTypeChecker
	def get_shift(self) -> enums.UnitShiftAreg:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:SHIFt \n
		Snippet: value: enums.UnitShiftAreg = driver.source.areGenerator.units.get_shift() \n
		No command help available \n
			:return: areg_unit_shift: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:UNITs:SHIFt?')
		return Conversions.str_to_scalar_enum(response, enums.UnitShiftAreg)

	def set_shift(self, areg_unit_shift: enums.UnitShiftAreg) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:SHIFt \n
		Snippet: driver.source.areGenerator.units.set_shift(areg_unit_shift = enums.UnitShiftAreg.HZ) \n
		No command help available \n
			:param areg_unit_shift: No help available
		"""
		param = Conversions.enum_scalar_to_str(areg_unit_shift, enums.UnitShiftAreg)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:UNITs:SHIFt {param}')

	# noinspection PyTypeChecker
	def get_speed(self) -> enums.UnitSpeedAreg:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:SPEed \n
		Snippet: value: enums.UnitSpeedAreg = driver.source.areGenerator.units.get_speed() \n
		Defines the speed unit. \n
			:return: areg_unit_speed: KMH| MPH| MPS KMH Kilometer per hour MPH Miles per Hour MPS Meter per Seconds
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:UNITs:SPEed?')
		return Conversions.str_to_scalar_enum(response, enums.UnitSpeedAreg)

	def set_speed(self, areg_unit_speed: enums.UnitSpeedAreg) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:UNITs:SPEed \n
		Snippet: driver.source.areGenerator.units.set_speed(areg_unit_speed = enums.UnitSpeedAreg.KMH) \n
		Defines the speed unit. \n
			:param areg_unit_speed: KMH| MPH| MPS KMH Kilometer per hour MPH Miles per Hour MPS Meter per Seconds
		"""
		param = Conversions.enum_scalar_to_str(areg_unit_speed, enums.UnitSpeedAreg)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:UNITs:SPEed {param}')



from enum import Enum


# noinspection SpellCheckingInspection
class AregDopplerUnit(Enum):
	"""2 Members, FREQuency ... SPEed"""
	FREQuency = 0
	SPEed = 1


# noinspection SpellCheckingInspection
class AregPowSens(Enum):
	"""5 Members, SEN1 ... UDEFined"""
	SEN1 = 0
	SEN2 = 1
	SEN3 = 2
	SEN4 = 3
	UDEFined = 4


# noinspection SpellCheckingInspection
class AregRadarPowIndicator(Enum):
	"""4 Members, BAD ... WEAK"""
	BAD = 0
	GOOD = 1
	OFF = 2
	WEAK = 3


# noinspection SpellCheckingInspection
class ByteOrder(Enum):
	"""2 Members, NORMal ... SWAPped"""
	NORMal = 0
	SWAPped = 1


# noinspection SpellCheckingInspection
class CalDataMode(Enum):
	"""2 Members, CUSTomer ... FACTory"""
	CUSTomer = 0
	FACTory = 1


# noinspection SpellCheckingInspection
class CalDataUpdate(Enum):
	"""6 Members, BBFRC ... RFFRC"""
	BBFRC = 0
	FREQuency = 1
	IALL = 2
	LEVel = 3
	LEVForced = 4
	RFFRC = 5


# noinspection SpellCheckingInspection
class Colour(Enum):
	"""4 Members, GREen ... YELLow"""
	GREen = 0
	NONE = 1
	RED = 2
	YELLow = 3


# noinspection SpellCheckingInspection
class DevExpFormat(Enum):
	"""4 Members, CGPRedefined ... XML"""
	CGPRedefined = 0
	CGUSer = 1
	SCPI = 2
	XML = 3


# noinspection SpellCheckingInspection
class DispKeybLockMode(Enum):
	"""5 Members, DISabled ... VNConly"""
	DISabled = 0
	DONLy = 1
	ENABled = 2
	TOFF = 3
	VNConly = 4


# noinspection SpellCheckingInspection
class ErFpowSensMapping(Enum):
	"""9 Members, SENS1 ... UNMapped"""
	SENS1 = 0
	SENS2 = 1
	SENS3 = 2
	SENS4 = 3
	SENSor1 = 4
	SENSor2 = 5
	SENSor3 = 6
	SENSor4 = 7
	UNMapped = 8


# noinspection SpellCheckingInspection
class ErFpowSensSourceAreg(Enum):
	"""1 Members, USER ... USER"""
	USER = 0


# noinspection SpellCheckingInspection
class FormData(Enum):
	"""2 Members, ASCii ... PACKed"""
	ASCii = 0
	PACKed = 1


# noinspection SpellCheckingInspection
class FormStatReg(Enum):
	"""4 Members, ASCii ... OCTal"""
	ASCii = 0
	BINary = 1
	HEXadecimal = 2
	OCTal = 3


# noinspection SpellCheckingInspection
class FrontPanelLayout(Enum):
	"""2 Members, DIGits ... LETTers"""
	DIGits = 0
	LETTers = 1


# noinspection SpellCheckingInspection
class HardCopyImageFormat(Enum):
	"""4 Members, BMP ... XPM"""
	BMP = 0
	JPG = 1
	PNG = 2
	XPM = 3


# noinspection SpellCheckingInspection
class HardCopyRegion(Enum):
	"""2 Members, ALL ... DIALog"""
	ALL = 0
	DIALog = 1


# noinspection SpellCheckingInspection
class IecDevId(Enum):
	"""2 Members, AUTO ... USER"""
	AUTO = 0
	USER = 1


# noinspection SpellCheckingInspection
class IecTermMode(Enum):
	"""2 Members, EOI ... STANdard"""
	EOI = 0
	STANdard = 1


# noinspection SpellCheckingInspection
class InclExcl(Enum):
	"""2 Members, EXCLude ... INCLude"""
	EXCLude = 0
	INCLude = 1


# noinspection SpellCheckingInspection
class KbLayout(Enum):
	"""20 Members, CHINese ... SWEDish"""
	CHINese = 0
	DANish = 1
	DUTBe = 2
	DUTCh = 3
	ENGLish = 4
	ENGUK = 5
	ENGUS = 6
	FINNish = 7
	FREBe = 8
	FRECa = 9
	FRENch = 10
	GERMan = 11
	ITALian = 12
	JAPanese = 13
	KORean = 14
	NORWegian = 15
	PORTuguese = 16
	RUSSian = 17
	SPANish = 18
	SWEDish = 19


# noinspection SpellCheckingInspection
class NetMode(Enum):
	"""2 Members, AUTO ... STATic"""
	AUTO = 0
	STATic = 1


# noinspection SpellCheckingInspection
class Parity(Enum):
	"""3 Members, EVEN ... ODD"""
	EVEN = 0
	NONE = 1
	ODD = 2


# noinspection SpellCheckingInspection
class PixelTestPredefined(Enum):
	"""9 Members, AUTO ... WHITe"""
	AUTO = 0
	BLACk = 1
	BLUE = 2
	GR25 = 3
	GR50 = 4
	GR75 = 5
	GREen = 6
	RED = 7
	WHITe = 8


# noinspection SpellCheckingInspection
class PowSensDisplayPriority(Enum):
	"""2 Members, AVERage ... PEAK"""
	AVERage = 0
	PEAK = 1


# noinspection SpellCheckingInspection
class PowSensFiltType(Enum):
	"""3 Members, AUTO ... USER"""
	AUTO = 0
	NSRatio = 1
	USER = 2


# noinspection SpellCheckingInspection
class RecScpiCmdMode(Enum):
	"""4 Members, AUTO ... OFF"""
	AUTO = 0
	DAUTo = 1
	MANual = 2
	OFF = 3


# noinspection SpellCheckingInspection
class RoscBandWidtExt(Enum):
	"""2 Members, NARRow ... WIDE"""
	NARRow = 0
	WIDE = 1


# noinspection SpellCheckingInspection
class RoscFreqExt(Enum):
	"""3 Members, _10MHZ ... _5MHZ"""
	_10MHZ = 0
	_13MHZ = 1
	_5MHZ = 2


# noinspection SpellCheckingInspection
class RoscSourSetup(Enum):
	"""3 Members, ELOop ... INTernal"""
	ELOop = 0
	EXTernal = 1
	INTernal = 2


# noinspection SpellCheckingInspection
class Rs232BdRate(Enum):
	"""7 Members, _115200 ... _9600"""
	_115200 = 0
	_19200 = 1
	_2400 = 2
	_38400 = 3
	_4800 = 4
	_57600 = 5
	_9600 = 6


# noinspection SpellCheckingInspection
class Rs232StopBits(Enum):
	"""2 Members, _1 ... _2"""
	_1 = 0
	_2 = 1


# noinspection SpellCheckingInspection
class SelftLev(Enum):
	"""3 Members, CUSTomer ... SERVice"""
	CUSTomer = 0
	PRODuction = 1
	SERVice = 2


# noinspection SpellCheckingInspection
class SelftLevWrite(Enum):
	"""4 Members, CUSTomer ... SERVice"""
	CUSTomer = 0
	NONE = 1
	PRODuction = 2
	SERVice = 3


# noinspection SpellCheckingInspection
class SlopeType(Enum):
	"""2 Members, NEGative ... POSitive"""
	NEGative = 0
	POSitive = 1


# noinspection SpellCheckingInspection
class StateExtended(Enum):
	"""3 Members, DEFault ... ON"""
	DEFault = 0
	OFF = 1
	ON = 2


# noinspection SpellCheckingInspection
class Test(Enum):
	"""4 Members, _0 ... STOPped"""
	_0 = 0
	_1 = 1
	RUNning = 2
	STOPped = 3


# noinspection SpellCheckingInspection
class TestCalSelected(Enum):
	"""2 Members, _0 ... _1"""
	_0 = 0
	_1 = 1


# noinspection SpellCheckingInspection
class TimeProtocol(Enum):
	"""6 Members, _0 ... ON"""
	_0 = 0
	_1 = 1
	NONE = 2
	NTP = 3
	OFF = 4
	ON = 5


# noinspection SpellCheckingInspection
class UnitAngleAreg(Enum):
	"""2 Members, DEGree ... RADian"""
	DEGree = 0
	RADian = 1


# noinspection SpellCheckingInspection
class UnitLengthAreg(Enum):
	"""3 Members, CM ... M"""
	CM = 0
	FT = 1
	M = 2


# noinspection SpellCheckingInspection
class UnitPowSens(Enum):
	"""3 Members, DBM ... WATT"""
	DBM = 0
	DBUV = 1
	WATT = 2


# noinspection SpellCheckingInspection
class UnitRcsAreg(Enum):
	"""2 Members, DBSM ... SM"""
	DBSM = 0
	SM = 1


# noinspection SpellCheckingInspection
class UnitShiftAreg(Enum):
	"""3 Members, HZ ... MHZ"""
	HZ = 0
	KHZ = 1
	MHZ = 2


# noinspection SpellCheckingInspection
class UnitSpeedAreg(Enum):
	"""3 Members, KMH ... MPS"""
	KMH = 0
	MPH = 1
	MPS = 2


# noinspection SpellCheckingInspection
class UpdPolicyMode(Enum):
	"""3 Members, CONFirm ... STRict"""
	CONFirm = 0
	IGNore = 1
	STRict = 2



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InputPyCls:
	"""InputPy commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("inputPy", core, parent)

	def get_nom_gain(self) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:INPut:NOMGain \n
		Snippet: value: float = driver.source.areGenerator.channel.inputPy.get_nom_gain() \n
		No command help available \n
			:return: areg_chan_nom_gain: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:INPut:NOMGain?')
		return Conversions.str_to_float(response)

	def set_nom_gain(self, areg_chan_nom_gain: float) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:INPut:NOMGain \n
		Snippet: driver.source.areGenerator.channel.inputPy.set_nom_gain(areg_chan_nom_gain = 1.0) \n
		No command help available \n
			:param areg_chan_nom_gain: No help available
		"""
		param = Conversions.decimal_value_to_str(areg_chan_nom_gain)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:CHANnel:INPut:NOMGain {param}')

	def get_rel_level(self) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:INPut:RELLevel \n
		Snippet: value: float = driver.source.areGenerator.channel.inputPy.get_rel_level() \n
		No command help available \n
			:return: areg_chan_rel_lev: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:INPut:RELLevel?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AttenuatorCls:
	"""Attenuator commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("attenuator", core, parent)

	def get_stage(self) -> int:
		"""SCPI: CALibration<HW>:LEVel:ATTenuator:STAGe \n
		Snippet: value: int = driver.calibration.level.attenuator.get_stage() \n
		No command help available \n
			:return: stage: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:ATTenuator:STAGe?')
		return Conversions.str_to_int(response)

	def set_stage(self, stage: int) -> None:
		"""SCPI: CALibration<HW>:LEVel:ATTenuator:STAGe \n
		Snippet: driver.calibration.level.attenuator.set_stage(stage = 1) \n
		No command help available \n
			:param stage: No help available
		"""
		param = Conversions.decimal_value_to_str(stage)
		self._core.io.write(f'CALibration<HwInstance>:LEVel:ATTenuator:STAGe {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GainCls:
	"""Gain commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gain", core, parent)

	def get_rx(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:ANTenna:REG:GAIN:RX \n
		Snippet: value: int = driver.source.areGenerator.radar.antenna.reg.gain.get_rx() \n
		Queries the antenna gain of the transmitting/receiving antenna.
		If [:SOURce<hw>]:AREGenerator:RADar:ANTenna:CUSTom[:STATe]1, you can define a customer-specific antenna gain value. \n
			:return: areg_ant_gain_rx: integer Range: 0 to 30
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:ANTenna:REG:GAIN:RX?')
		return Conversions.str_to_int(response)

	def set_rx(self, areg_ant_gain_rx: int) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:ANTenna:REG:GAIN:RX \n
		Snippet: driver.source.areGenerator.radar.antenna.reg.gain.set_rx(areg_ant_gain_rx = 1) \n
		Queries the antenna gain of the transmitting/receiving antenna.
		If [:SOURce<hw>]:AREGenerator:RADar:ANTenna:CUSTom[:STATe]1, you can define a customer-specific antenna gain value. \n
			:param areg_ant_gain_rx: integer Range: 0 to 30
		"""
		param = Conversions.decimal_value_to_str(areg_ant_gain_rx)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:RADar:ANTenna:REG:GAIN:RX {param}')

	def get_tx(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:ANTenna:REG:GAIN:TX \n
		Snippet: value: int = driver.source.areGenerator.radar.antenna.reg.gain.get_tx() \n
		Queries the antenna gain of the transmitting/receiving antenna.
		If [:SOURce<hw>]:AREGenerator:RADar:ANTenna:CUSTom[:STATe]1, you can define a customer-specific antenna gain value. \n
			:return: areg_ant_gain_tx: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:ANTenna:REG:GAIN:TX?')
		return Conversions.str_to_int(response)

	def set_tx(self, areg_ant_gain_tx: int) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:ANTenna:REG:GAIN:TX \n
		Snippet: driver.source.areGenerator.radar.antenna.reg.gain.set_tx(areg_ant_gain_tx = 1) \n
		Queries the antenna gain of the transmitting/receiving antenna.
		If [:SOURce<hw>]:AREGenerator:RADar:ANTenna:CUSTom[:STATe]1, you can define a customer-specific antenna gain value. \n
			:param areg_ant_gain_tx: integer Range: 0 to 30
		"""
		param = Conversions.decimal_value_to_str(areg_ant_gain_tx)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:RADar:ANTenna:REG:GAIN:TX {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AreGeneratorCls:
	"""AreGenerator commands group definition. 31 total commands, 5 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("areGenerator", core, parent)

	@property
	def channel(self):
		"""channel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_channel'):
			from .Channel import ChannelCls
			self._channel = ChannelCls(self._core, self._cmd_group)
		return self._channel

	@property
	def object(self):
		"""object commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_object'):
			from .Object import ObjectCls
			self._object = ObjectCls(self._core, self._cmd_group)
		return self._object

	@property
	def osetup(self):
		"""osetup commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_osetup'):
			from .Osetup import OsetupCls
			self._osetup = OsetupCls(self._core, self._cmd_group)
		return self._osetup

	@property
	def radar(self):
		"""radar commands group. 6 Sub-classes, 1 commands."""
		if not hasattr(self, '_radar'):
			from .Radar import RadarCls
			self._radar = RadarCls(self._core, self._cmd_group)
		return self._radar

	@property
	def units(self):
		"""units commands group. 0 Sub-classes, 6 commands."""
		if not hasattr(self, '_units'):
			from .Units import UnitsCls
			self._units = UnitsCls(self._core, self._cmd_group)
		return self._units

	def clone(self) -> 'AreGeneratorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AreGeneratorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 5 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	@property
	def measure(self):
		"""measure commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_measure'):
			from .Measure import MeasureCls
			self._measure = MeasureCls(self._core, self._cmd_group)
		return self._measure

	def get_date(self) -> str:
		"""SCPI: CALibration<HW>:ALL:DATE \n
		Snippet: value: str = driver.calibration.all.get_date() \n
		Queries the date of the most recently executed full adjustment. \n
			:return: date: string
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:ALL:DATE?')
		return trim_str_response(response)

	def get_information(self) -> str:
		"""SCPI: CALibration<HW>:ALL:INFormation \n
		Snippet: value: str = driver.calibration.all.get_information() \n
		Queries the current state of the internal adjustment. \n
			:return: cal_info_text: string
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:ALL:INFormation?')
		return trim_str_response(response)

	def get_temp(self) -> str:
		"""SCPI: CALibration<HW>:ALL:TEMP \n
		Snippet: value: str = driver.calibration.all.get_temp() \n
		Queries the temperature deviation compared to the calibration temperature. \n
			:return: temperature: string
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:ALL:TEMP?')
		return trim_str_response(response)

	def get_time(self) -> str:
		"""SCPI: CALibration<HW>:ALL:TIME \n
		Snippet: value: str = driver.calibration.all.get_time() \n
		Queries the time elapsed since the last full adjustment. \n
			:return: time: string
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:ALL:TIME?')
		return trim_str_response(response)

	def clone(self) -> 'AllCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AllCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OtaCls:
	"""Ota commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ota", core, parent)

	def get_offset(self) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:OTA:OFFSet \n
		Snippet: value: float = driver.source.areGenerator.radar.ota.get_offset() \n
		Defines the distance (air gap) from the R&S AREG100A to the RUT (radar under test) . \n
			:return: areg_ota_offset: float Range: 0.01 to 10, Unit: m
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:OTA:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, areg_ota_offset: float) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:OTA:OFFSet \n
		Snippet: driver.source.areGenerator.radar.ota.set_offset(areg_ota_offset = 1.0) \n
		Defines the distance (air gap) from the R&S AREG100A to the RUT (radar under test) . \n
			:param areg_ota_offset: float Range: 0.01 to 10, Unit: m
		"""
		param = Conversions.decimal_value_to_str(areg_ota_offset)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:RADar:OTA:OFFSet {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CustomCls:
	"""Custom commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("custom", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:ANTenna:CUSTom:[STATe] \n
		Snippet: value: bool = driver.source.areGenerator.radar.antenna.custom.get_state() \n
			INTRO_CMD_HELP: If enabled, you can use a custom antenna and define the transmitting and receiving gain values with the commands: \n
			- [:SOURce<hw>]:AREGenerator:RADar:ANTenna:REG:GAIN:TX
			- [:SOURce<hw>]:AREGenerator:RADar:ANTenna:REG:GAIN:RX. \n
			:return: areg_ant_cust_stat: 0| 1| OFF| ON 0 | OFF The predefined antenna gain settings for transmitting and receiving antenna are used. 1 | ON The customer-specific antenna gain settings for transmitting and receiving antenna apply.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:ANTenna:CUSTom:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, areg_ant_cust_stat: bool) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:ANTenna:CUSTom:[STATe] \n
		Snippet: driver.source.areGenerator.radar.antenna.custom.set_state(areg_ant_cust_stat = False) \n
			INTRO_CMD_HELP: If enabled, you can use a custom antenna and define the transmitting and receiving gain values with the commands: \n
			- [:SOURce<hw>]:AREGenerator:RADar:ANTenna:REG:GAIN:TX
			- [:SOURce<hw>]:AREGenerator:RADar:ANTenna:REG:GAIN:RX. \n
			:param areg_ant_cust_stat: 0| 1| OFF| ON 0 | OFF The predefined antenna gain settings for transmitting and receiving antenna are used. 1 | ON The customer-specific antenna gain settings for transmitting and receiving antenna apply.
		"""
		param = Conversions.bool_to_str(areg_ant_cust_stat)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:RADar:ANTenna:CUSTom:STATe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExternalCls:
	"""External commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("external", core, parent)

	@property
	def rfOff(self):
		"""rfOff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfOff'):
			from .RfOff import RfOffCls
			self._rfOff = RfOffCls(self._core, self._cmd_group)
		return self._rfOff

	# noinspection PyTypeChecker
	def get_frequency(self) -> enums.RoscFreqExt:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:FREQuency \n
		Snippet: value: enums.RoscFreqExt = driver.source.roscillator.external.get_frequency() \n
		No command help available \n
			:return: frequency: No help available
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:EXTernal:FREQuency?')
		return Conversions.str_to_scalar_enum(response, enums.RoscFreqExt)

	def set_frequency(self, frequency: enums.RoscFreqExt) -> None:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:FREQuency \n
		Snippet: driver.source.roscillator.external.set_frequency(frequency = enums.RoscFreqExt._10MHZ) \n
		No command help available \n
			:param frequency: No help available
		"""
		param = Conversions.enum_scalar_to_str(frequency, enums.RoscFreqExt)
		self._core.io.write(f'SOURce:ROSCillator:EXTernal:FREQuency {param}')

	# noinspection PyTypeChecker
	def get_sbandwidth(self) -> enums.RoscBandWidtExt:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:SBANdwidth \n
		Snippet: value: enums.RoscBandWidtExt = driver.source.roscillator.external.get_sbandwidth() \n
		No command help available \n
			:return: sbandwidth: No help available
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:EXTernal:SBANdwidth?')
		return Conversions.str_to_scalar_enum(response, enums.RoscBandWidtExt)

	def set_sbandwidth(self, sbandwidth: enums.RoscBandWidtExt) -> None:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:SBANdwidth \n
		Snippet: driver.source.roscillator.external.set_sbandwidth(sbandwidth = enums.RoscBandWidtExt.NARRow) \n
		No command help available \n
			:param sbandwidth: No help available
		"""
		param = Conversions.enum_scalar_to_str(sbandwidth, enums.RoscBandWidtExt)
		self._core.io.write(f'SOURce:ROSCillator:EXTernal:SBANdwidth {param}')

	def clone(self) -> 'ExternalCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ExternalCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get_max(self) -> float:
		"""SCPI: SYSTem:PROFiling:RECord:COUNt:MAX \n
		Snippet: value: float = driver.system.profiling.record.count.get_max() \n
		No command help available \n
			:return: count: No help available
		"""
		response = self._core.io.query_str('SYSTem:PROFiling:RECord:COUNt:MAX?')
		return Conversions.str_to_float(response)

	def set_max(self, count: float) -> None:
		"""SCPI: SYSTem:PROFiling:RECord:COUNt:MAX \n
		Snippet: driver.system.profiling.record.count.set_max(count = 1.0) \n
		No command help available \n
			:param count: No help available
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'SYSTem:PROFiling:RECord:COUNt:MAX {param}')

	def get_value(self) -> float:
		"""SCPI: SYSTem:PROFiling:RECord:COUNt \n
		Snippet: value: float = driver.system.profiling.record.count.get_value() \n
		No command help available \n
			:return: count: No help available
		"""
		response = self._core.io.query_str('SYSTem:PROFiling:RECord:COUNt?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DelayCls:
	"""Delay commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("delay", core, parent)

	@property
	def shutdown(self):
		"""shutdown commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_shutdown'):
			from .Shutdown import ShutdownCls
			self._shutdown = ShutdownCls(self._core, self._cmd_group)
		return self._shutdown

	def get_minutes(self) -> int:
		"""SCPI: CALibration:DELay:MINutes \n
		Snippet: value: int = driver.calibration.delay.get_minutes() \n
		No command help available \n
			:return: minutes: No help available
		"""
		response = self._core.io.query_str('CALibration:DELay:MINutes?')
		return Conversions.str_to_int(response)

	def set_minutes(self, minutes: int) -> None:
		"""SCPI: CALibration:DELay:MINutes \n
		Snippet: driver.calibration.delay.set_minutes(minutes = 1) \n
		No command help available \n
			:param minutes: No help available
		"""
		param = Conversions.decimal_value_to_str(minutes)
		self._core.io.write(f'CALibration:DELay:MINutes {param}')

	def get_measure(self) -> bool:
		"""SCPI: CALibration:DELay:[MEASure] \n
		Snippet: value: bool = driver.calibration.delay.get_measure() \n
		No command help available \n
			:return: error: No help available
		"""
		response = self._core.io.query_str('CALibration:DELay:MEASure?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'DelayCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DelayCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScanCls:
	"""Scan commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scan", core, parent)

	@property
	def usensor(self):
		"""usensor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_usensor'):
			from .Usensor import UsensorCls
			self._usensor = UsensorCls(self._core, self._cmd_group)
		return self._usensor

	def set_lsensor(self, ip: str) -> None:
		"""SCPI: SLISt:SCAN:LSENsor \n
		Snippet: driver.slist.scan.set_lsensor(ip = 'abc') \n
		Scans for R&S NRP power sensors connected in the LAN. \n
			:param ip: string
		"""
		param = Conversions.value_to_quoted_str(ip)
		self._core.io.write(f'SLISt:SCAN:LSENsor {param}')

	def get_state(self) -> bool:
		"""SCPI: SLISt:SCAN:[STATe] \n
		Snippet: value: bool = driver.slist.scan.get_state() \n
		Starts the search for R&S NRP power sensors, connected in the LAN or via the USBTMC protocol. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SLISt:SCAN:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: SLISt:SCAN:[STATe] \n
		Snippet: driver.slist.scan.set_state(state = False) \n
		Starts the search for R&S NRP power sensors, connected in the LAN or via the USBTMC protocol. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SLISt:SCAN:STATe {param}')

	def clone(self) -> 'ScanCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ScanCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, areg_obj_state: bool, objectIx=repcap.ObjectIx.Default, subchannel=repcap.Subchannel.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJect<CH>:[SUBChannel<ST>]:[STATe] \n
		Snippet: driver.source.areGenerator.object.subChannel.state.set(areg_obj_state = False, objectIx = repcap.ObjectIx.Default, subchannel = repcap.Subchannel.Default) \n
		No command help available \n
			:param areg_obj_state: No help available
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
		"""
		param = Conversions.bool_to_str(areg_obj_state)
		objectIx_cmd_val = self._cmd_group.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OBJect{objectIx_cmd_val}:SUBChannel{subchannel_cmd_val}:STATe {param}')

	def get(self, objectIx=repcap.ObjectIx.Default, subchannel=repcap.Subchannel.Default) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJect<CH>:[SUBChannel<ST>]:[STATe] \n
		Snippet: value: bool = driver.source.areGenerator.object.subChannel.state.get(objectIx = repcap.ObjectIx.Default, subchannel = repcap.Subchannel.Default) \n
		No command help available \n
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:return: areg_obj_state: No help available"""
		objectIx_cmd_val = self._cmd_group.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		subchannel_cmd_val = self._cmd_group.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:OBJect{objectIx_cmd_val}:SUBChannel{subchannel_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HelpCls:
	"""Help commands group definition. 4 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("help", core, parent)

	@property
	def syntax(self):
		"""syntax commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_syntax'):
			from .Syntax import SyntaxCls
			self._syntax = SyntaxCls(self._core, self._cmd_group)
		return self._syntax

	def export(self) -> None:
		"""SCPI: SYSTem:HELP:EXPort \n
		Snippet: driver.system.help.export() \n
		Saves the online help as zip archive in the user directory. \n
		"""
		self._core.io.write(f'SYSTem:HELP:EXPort')

	def export_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:HELP:EXPort \n
		Snippet: driver.system.help.export_with_opc() \n
		Saves the online help as zip archive in the user directory. \n
		Same as export, but waits for the operation to complete before continuing further. Use the RsAreg.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:HELP:EXPort', opc_timeout_ms)

	def get_headers(self) -> str:
		"""SCPI: SYSTem:HELP:HEADers \n
		Snippet: value: str = driver.system.help.get_headers() \n
		No command help available \n
			:return: headers: No help available
		"""
		response = self._core.io.query_str('SYSTem:HELP:HEADers?')
		return trim_str_response(response)

	def clone(self) -> 'HelpCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HelpCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MultiInstrumentCls:
	"""MultiInstrument commands group definition. 5 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("multiInstrument", core, parent)

	@property
	def connect(self):
		"""connect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_connect'):
			from .Connect import ConnectCls
			self._connect = ConnectCls(self._core, self._cmd_group)
		return self._connect

	@property
	def remove(self):
		"""remove commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_remove'):
			from .Remove import RemoveCls
			self._remove = RemoveCls(self._core, self._cmd_group)
		return self._remove

	@property
	def secondary(self):
		"""secondary commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_secondary'):
			from .Secondary import SecondaryCls
			self._secondary = SecondaryCls(self._core, self._cmd_group)
		return self._secondary

	def clone(self) -> 'MultiInstrumentCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MultiInstrumentCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AdjustCls:
	"""Adjust commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("adjust", core, parent)

	def get_value(self) -> int:
		"""SCPI: [SOURce]:ROSCillator:[INTernal]:ADJust:VALue \n
		Snippet: value: int = driver.source.roscillator.internal.adjust.get_value() \n
		No command help available \n
			:return: value: No help available
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:INTernal:ADJust:VALue?')
		return Conversions.str_to_int(response)

	def set_value(self, value: int) -> None:
		"""SCPI: [SOURce]:ROSCillator:[INTernal]:ADJust:VALue \n
		Snippet: driver.source.roscillator.internal.adjust.set_value(value = 1) \n
		No command help available \n
			:param value: No help available
		"""
		param = Conversions.decimal_value_to_str(value)
		self._core.io.write(f'SOURce:ROSCillator:INTernal:ADJust:VALue {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce]:ROSCillator:[INTernal]:ADJust:[STATe] \n
		Snippet: value: bool = driver.source.roscillator.internal.adjust.get_state() \n
		Determines whether the calibrated (off) or a user-defined (on) adjustment value is used for fine adjustment of the
		frequency. \n
			:return: state: 0| 1| OFF| ON 0 Fine adjustment with the calibrated frequency value 1 User-defined adjustment value. The instrument is no longer in the calibrated state. The calibration value is, however, not changed. The instrument resumes the calibrated state if you send SOURce:ROSCillator:INTernal:ADJust:STATe 0.
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:INTernal:ADJust:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce]:ROSCillator:[INTernal]:ADJust:[STATe] \n
		Snippet: driver.source.roscillator.internal.adjust.set_state(state = False) \n
		Determines whether the calibrated (off) or a user-defined (on) adjustment value is used for fine adjustment of the
		frequency. \n
			:param state: 0| 1| OFF| ON 0 Fine adjustment with the calibrated frequency value 1 User-defined adjustment value. The instrument is no longer in the calibrated state. The calibration value is, however, not changed. The instrument resumes the calibrated state if you send SOURce:ROSCillator:INTernal:ADJust:STATe 0.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce:ROSCillator:INTernal:ADJust:STATe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CwCls:
	"""Cw commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cw", core, parent)

	# noinspection PyTypeChecker
	def get_recall(self) -> enums.InclExcl:
		"""SCPI: [SOURce<HW>]:FREQuency:[CW]:RCL \n
		Snippet: value: enums.InclExcl = driver.source.frequency.cw.get_recall() \n
		Set whether the RF frequency value is retained or taken from a loaded instrument configuration, when you recall
		instrument settings with command *RCL. \n
			:return: rcl: INCLude| EXCLude INCLude Takes the frequency value of the loaded settings. EXCLude Retains the current frequency when an instrument configuration is loaded.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FREQuency:CW:RCL?')
		return Conversions.str_to_scalar_enum(response, enums.InclExcl)

	def set_recall(self, rcl: enums.InclExcl) -> None:
		"""SCPI: [SOURce<HW>]:FREQuency:[CW]:RCL \n
		Snippet: driver.source.frequency.cw.set_recall(rcl = enums.InclExcl.EXCLude) \n
		Set whether the RF frequency value is retained or taken from a loaded instrument configuration, when you recall
		instrument settings with command *RCL. \n
			:param rcl: INCLude| EXCLude INCLude Takes the frequency value of the loaded settings. EXCLude Retains the current frequency when an instrument configuration is loaded.
		"""
		param = Conversions.enum_scalar_to_str(rcl, enums.InclExcl)
		self._core.io.write(f'SOURce<HwInstance>:FREQuency:CW:RCL {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:FREQuency:[CW] \n
		Snippet: value: float = driver.source.frequency.cw.get_value() \n
		R&S AREG-B124/-B177: queries the center frequency. R&S AREG-B181: sets the center frequency of the RF output signal. \n
			:return: frequency: float Range: R&S AREG-B124: 24 GHz, R&S AREG-B177: 77 GHz, R&S AREG-B181: 78 GHz and 79 GHz
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FREQuency:CW?')
		return Conversions.str_to_float(response)

	def set_value(self, frequency: float) -> None:
		"""SCPI: [SOURce<HW>]:FREQuency:[CW] \n
		Snippet: driver.source.frequency.cw.set_value(frequency = 1.0) \n
		R&S AREG-B124/-B177: queries the center frequency. R&S AREG-B181: sets the center frequency of the RF output signal. \n
			:param frequency: float Range: R&S AREG-B124: 24 GHz, R&S AREG-B177: 77 GHz, R&S AREG-B181: 78 GHz and 79 GHz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SOURce<HwInstance>:FREQuency:CW {param}')
